@@ -1,8 +1,8 @@
 
-/* Generated data (by glib-mkenums) */
 
-#ifndef __ENUM_GTYPES_H__
-#define __ENUM_GTYPES_H__
+
+#ifndef SRC_ENUM_GTYPES_H_
+#define SRC_ENUM_GTYPES_H_
 #include <glib-object.h>
 G_BEGIN_DECLS
 /* enumerations from "parole-button.h" */
@@ -10,7 +10,7 @@ GType parole_button_key_get_type (void);
 #define ENUM_GTYPE_BUTTON_KEY (parole_button_key_get_type())
 G_END_DECLS
 
-#endif /* __ENUM_GTYPES_H__ */
+#endif /* SRC_ENUM_GTYPES_H_ */
+
 
-/* Generated data ends here */
 
