@@ -1,8 +1,8 @@
 
 
 
-#ifndef __GST_ENUM_TYPE_H__
-#define __GST_ENUM_TYPE_H__
+#ifndef SRC_GST_GST_ENUM_TYPES_H_
+#define SRC_GST_GST_ENUM_TYPES_H_
 #include <glib-object.h>
 G_BEGIN_DECLS
 /* enumerations from "parole-gst.h" */
@@ -10,7 +10,7 @@ GType parole_aspect_ratio_get_type (void);
 #define GST_ENUM_TYPE_ASPECT_RATIO (parole_aspect_ratio_get_type())
 G_END_DECLS
 
-#endif /* __GST_ENUM_TYPE_H__ */
+#endif /* SRC_GST_GST_ENUM_TYPES_H_ */
 
 
 
