@@ -63,9 +63,9 @@ _gmarshal_VOID__OBJECT_ENUM (GClosure     *closure,
                                                   gpointer     arg_1,
                                                   gint         arg_2,
                                                   gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_ENUM callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_ENUM callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -100,9 +100,9 @@ _gmarshal_VOID__OBJECT_INT64 (GClosure     *closure,
                                                    gpointer     arg_1,
                                                    gint64       arg_2,
                                                    gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_INT64 callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_INT64 callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -137,9 +137,9 @@ _gmarshal_VOID__OBJECT_INT (GClosure     *closure,
                                                  gpointer     arg_1,
                                                  gint         arg_2,
                                                  gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -174,9 +174,9 @@ _gmarshal_VOID__OBJECT_DOUBLE (GClosure     *closure,
                                                     gpointer     arg_1,
                                                     gdouble      arg_2,
                                                     gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_DOUBLE callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_DOUBLE callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
