@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
+ * * Copyright (C) 2012-2017 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2017 Simon Steinbeiß <ochosi@xfce.org
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -20,35 +20,58 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __PAROLE_H_
-#define __PAROLE_H_
+#ifndef SRC_MISC_PAROLE_H_
+#define SRC_MISC_PAROLE_H_
 
 #define __PAROLE_H_INSIDE__
 
 #include <glib-object.h>
 
-#include <src/misc/parole-provider-plugin.h>
-#include <src/misc/parole-provider-player.h>
-#include <src/misc/parole-file.h>
-#include <src/misc/parole-stream.h>
-#include <src/misc/parole-pl-parser.h>
-#include <src/misc/parole-filters.h>
-#include <src/misc/parole-debug.h>
-
 #include <libxfce4util/libxfce4util.h>
 
+#include "src/misc/parole-debug.h"
+#include "src/misc/parole-file.h"
+#include "src/misc/parole-filters.h"
+#include "src/misc/parole-pl-parser.h"
+#include "src/misc/parole-provider-player.h"
+#include "src/misc/parole-provider-plugin.h"
+#include "src/misc/parole-stream.h"
+
+/**
+ * PAROLE_MAJOR_VERSION:
+ *
+ * Major version number.
+ *
+ * Since: 0.2
+ */
 #define PAROLE_MAJOR_VERSION		0
-#define PAROLE_MINOR_VERSION		7
-#define PAROLE_MICRO_VERSION		0
+
+/**
+ * PAROLE_MINOR_VERSION:
+ *
+ * Minor version number.
+ *
+ * Since: 0.2
+ */
+#define PAROLE_MINOR_VERSION		9
+
+/**
+ * PAROLE_MICRO_VERSION:
+ *
+ * Micro version number.
+ *
+ * Since: 0.2
+ */
+#define PAROLE_MICRO_VERSION		2
 
 /**
  * PAROLE_CHECK_VERSION:
- * @major: major version number.
- * @minor: minor version number.
- * @micro: micor version number.
- * 
+ * @major: major version number
+ * @minor: minor version number
+ * @micro: micro version number
+ *
  * Checks the parole version.
- * 
+ *
  * Since: 0.2
  */
 #define	PAROLE_CHECK_VERSION(major,minor,micro)					\
@@ -62,54 +85,64 @@
  */
 /**
  * PAROLE_DEFINE_TYPE:
- * @TN: The name of the new type, in Camel case.
- * @t_n: The name of the new type, in lowercase, with words separated by '_'.
- * @T_P: The #GType of the parent type.
- * 
+ * @TN: The name of the new type, in Camel case
+ * @t_n: The name of the new type, in lowercase, with words separated by '_'
+ * @T_P: The #GType of the parent type
+ *
+ * Create a new type definition.
+ *
  * Since: 0.2
  */
-#define PAROLE_DEFINE_TYPE(TN, t_n, T_P)			PAROLE_DEFINE_TYPE_EXTENDED (TN, t_n, T_P, 0, {})
+#define PAROLE_DEFINE_TYPE(TN, t_n, T_P) PAROLE_DEFINE_TYPE_EXTENDED (TN, t_n, T_P, 0, {})
 
 /**
  * PAROLE_DEFINE_TYPE_EXTENDED:
- * @TN: The name of the new type, in Camel case.
- * @t_n: The name of the new type, in lowercase, with words separated by '_'.
- * @T_P: The #GType of the parent type.
- * @_f_: #GTypeFlags to pass to g_type_module_register_type ().
- * @_C_: Custom code that gets inserted in *_get_type() function.
- * 
+ * @TN: The name of the new type, in Camel case
+ * @t_n: The name of the new type, in lowercase, with words separated by '_'
+ * @T_P: The #GType of the parent type
+ * @_f_: #GTypeFlags to pass to g_type_module_register_type ()
+ * @_C_: Custom code that gets inserted in *_get_type() function
+ *
+ * Create a new type definition, passing flags and custom code to be inserted in the *_get_type() function.
+ *
  * Since: 0.2
  */
 #define PAROLE_DEFINE_TYPE_EXTENDED(TN, t_n, T_P, _f_, _C_)	_PAROLE_DEFINE_TYPE_EXTENDED_BEGIN(TN, t_n, T_P, _f_) {_C_;} _PAROLE_DEFINE_TYPE_EXTENDED_END()
 
 /**
  * PAROLE_DEFINE_TYPE_WITH_CODE:
- * @TN: The name of the new type, in Camel case.
- * @t_n: The name of the new type, in lowercase, with words separated by '_'.
- * @T_P: The #GType of the parent type.
- * @_C_: Custom code that gets inserted in *_get_type() function.
- * 
+ * @TN: The name of the new type, in Camel case
+ * @t_n: The name of the new type, in lowercase, with words separated by '_'
+ * @T_P: The #GType of the parent type
+ * @_C_: Custom code that gets inserted in *_get_type() function
+ *
+ * Create a new type definition, passing custom code to be inserted in the *_get_type() function.
+ *
  * Since: 0.2
  */
-#define PAROLE_DEFINE_TYPE_WITH_CODE(TN, t_n, T_P, _C_)		_PAROLE_DEFINE_TYPE_EXTENDED_BEGIN(TN, t_n, T_P, 0) {_C_;} _PAROLE_DEFINE_TYPE_EXTENDED_END()
+#define PAROLE_DEFINE_TYPE_WITH_CODE(TN, t_n, T_P, _C_)	_PAROLE_DEFINE_TYPE_EXTENDED_BEGIN(TN, t_n, T_P, 0) {_C_;} _PAROLE_DEFINE_TYPE_EXTENDED_END()
 
 /**
  * PAROLE_DEFINE_ABSTRACT_TYPE:
- * @TN: The name of the new type, in Camel case.
- * @t_n: The name of the new type, in lowercase, with words separated by '_'.
- * @T_P: The #GType of the parent type.
- * 
+ * @TN: The name of the new type, in Camel case
+ * @t_n: The name of the new type, in lowercase, with words separated by '_'
+ * @T_P: The #GType of the parent type
+ *
+ * Create a new abstract type definition.
+ *
  * Since: 0.2
  */
-#define PAROLE_DEFINE_ABSTRACT_TYPE(TN, t_n, T_P)		PAROLE_DEFINE_TYPE_EXTENDED (TN, t_n, T_P, G_TYPE_FLAG_ABSTRACT, {})
+#define PAROLE_DEFINE_ABSTRACT_TYPE(TN, t_n, T_P) PAROLE_DEFINE_TYPE_EXTENDED (TN, t_n, T_P, G_TYPE_FLAG_ABSTRACT, {})
 
 /**
  * PAROLE_DEFINE_ABSTRACT_TYPE_WITH_CODE:
- * @TN: The name of the new type, in Camel case.
- * @t_n: The name of the new type, in lowercase, with words separated by '_'.
- * @T_P: The #GType of the parent type.
- * @_C_: Custom code that gets inserted in *_get_type() function.
- * 
+ * @TN: The name of the new type, in Camel case
+ * @t_n: The name of the new type, in lowercase, with words separated by '_'
+ * @T_P: The #GType of the parent type
+ * @_C_: Custom code that gets inserted in *_get_type() function
+ *
+ * Create a new abstract type definition, passing custom code to be inserted in the *_get_type() function.
+ *
  * Since: 0.2
  */
 #define PAROLE_DEFINE_ABSTRACT_TYPE_WITH_CODE(TN, t_n, T_P, _C_) PAROLE_DEFINE_TYPE_EXTENDED (TN, t_n, T_P, G_TYPE_FLAG_ABSTRACT, _C_)
@@ -168,8 +201,11 @@ type_name##_register_type (ParoleProviderPlugin *provider_plugin_def) 		\
 
 /**
  * PAROLE_IMPLEMENT_INTERFACE:
- * @TYPE_IFACE: the #GType of the interface to add.
- * @iface_init: The interface init function.
+ * @TYPE_IFACE: the #GType of the interface to add
+ * @iface_init: The interface init function
+ *
+ * Convenience function for interface implementation.
+ *
  */
 #define PAROLE_IMPLEMENT_INTERFACE(TYPE_IFACE, iface_init) 			\
 { 										\
@@ -187,4 +223,4 @@ type_name##_register_type (ParoleProviderPlugin *provider_plugin_def) 		\
 
 #undef __PAROLE_H_INSIDE__
 
-#endif /*__PAROLE_H_*/
+#endif /* SRC_MISC_PAROLE_H_ */
